@@ -1,6 +1,6 @@
-\dontrun{
+\donttest{
 # Load the Gorilla data
-data(gorillas)
+data(gorillas, package = "inlabru")
  
 # Create a base map centered around the nests and plot the boundary as well as the nests
 gmap(gorillas$nests, maptype = "satellite") + 
