@@ -1,4 +1,4 @@
-
+\donttest{
 # Generate some data
 input.df <- data.frame(x=cos(1:10))
 input.df <- within(input.df, y <- 5 + 2*cos(1:10) + rnorm(10, mean=0, sd=0.1))
@@ -38,3 +38,4 @@ xipost
 rownames(xipost) = c("x","Intercept")
 ggplot() + gg(xipost, bar = TRUE)
                  
+}
\ No newline at end of file
